==> zio-aws-ec2_2.13-5.17.104.7-sources.jar: zio/aws/ec2/model/InstanceCount.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class InstanceCount(
    instanceCount: Option[Integer] = None,
    state: Option[zio.aws.ec2.model.ListingState] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.InstanceCount = {
    import InstanceCount.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.InstanceCount
      .builder()
      .optionallyWith(
        instanceCount.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.instanceCount)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.InstanceCount.ReadOnly =
    zio.aws.ec2.model.InstanceCount.wrap(buildAwsValue())
}
object InstanceCount {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.ec2.model.InstanceCount] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.InstanceCount =
      zio.aws.ec2.model.InstanceCount(
        instanceCount.map(value => value),
        state.map(value => value)
      )
    def instanceCount: Option[Integer]
    def state: Option[zio.aws.ec2.model.ListingState]
    def getInstanceCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("instanceCount", instanceCount)
    def getState: ZIO[Any, AwsError, zio.aws.ec2.model.ListingState] =
      AwsError.unwrapOptionField("state", state)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.InstanceCount
  ) extends zio.aws.ec2.model.InstanceCount.ReadOnly {
    override val instanceCount: Option[Integer] = scala
      .Option(impl.instanceCount())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val state: Option[zio.aws.ec2.model.ListingState] = scala
      .Option(impl.state())
      .map(value => zio.aws.ec2.model.ListingState.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.InstanceCount
  ): zio.aws.ec2.model.InstanceCount.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.157.2-sources.jar: zio/aws/ec2/model/InstanceCount.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class InstanceCount(
    instanceCount: Option[Integer] = None,
    state: Option[zio.aws.ec2.model.ListingState] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.InstanceCount = {
    import InstanceCount.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.InstanceCount
      .builder()
      .optionallyWith(instanceCount.map(value => value: java.lang.Integer))(
        _.instanceCount
      )
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.InstanceCount.ReadOnly =
    zio.aws.ec2.model.InstanceCount.wrap(buildAwsValue())
}
object InstanceCount {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.ec2.model.InstanceCount] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.InstanceCount =
      zio.aws.ec2.model.InstanceCount(
        instanceCount.map(value => value),
        state.map(value => value)
      )
    def instanceCount: Option[Integer]
    def state: Option[zio.aws.ec2.model.ListingState]
    def getInstanceCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("instanceCount", instanceCount)
    def getState: ZIO[Any, AwsError, zio.aws.ec2.model.ListingState] =
      AwsError.unwrapOptionField("state", state)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.InstanceCount
  ) extends zio.aws.ec2.model.InstanceCount.ReadOnly {
    override val instanceCount: Option[Integer] =
      scala.Option(impl.instanceCount()).map(value => value: Integer)
    override val state: Option[zio.aws.ec2.model.ListingState] = scala
      .Option(impl.state())
      .map(value => zio.aws.ec2.model.ListingState.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.InstanceCount
  ): zio.aws.ec2.model.InstanceCount.ReadOnly = new Wrapper(impl)
}
